@@ -33,12 +33,12 @@
 #include <string.h>
 #include <panel-applet.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
 
 #include "egg-debug.h"
-#include "egg-dbus-monitor.h"
 #include "gpm-common.h"
 
 #define GPM_TYPE_BRIGHTNESS_APPLET		(gpm_brightness_applet_get_type ())
@@ -61,7 +61,7 @@ typedef struct{
 	/* connection to g-p-m */
 	DBusGProxy *proxy;
 	DBusGConnection *connection;
-	EggDbusMonitor *monitor;
+	guint bus_watch_id;
 	guint level;
 	/* a cache for panel size */
 	gint size;
@@ -97,12 +97,12 @@ static gboolean  gpm_applet_scroll_cb             (GpmBrightnessApplet *applet,
 static gboolean  gpm_applet_slide_cb              (GtkWidget *w, GpmBrightnessApplet *applet);
 static void      gpm_applet_create_popup          (GpmBrightnessApplet *applet);
 static gboolean  gpm_applet_popup_cb              (GpmBrightnessApplet *applet, GdkEventButton *event);
-static void      gpm_applet_dialog_about_cb       (BonoboUIComponent *uic, gpointer data, const gchar *verbname);
+static void      gpm_applet_dialog_about_cb       (GtkAction *action, gpointer data);
 static gboolean  gpm_applet_bonobo_cb             (PanelApplet *_applet, const gchar *iid, gpointer data);
 static void      gpm_applet_destroy_cb            (GtkObject *object);
 
-#define GPM_BRIGHTNESS_APPLET_OAFID		"OAFIID:GNOME_BrightnessApplet"
-#define GPM_BRIGHTNESS_APPLET_FACTORY_OAFID	"OAFIID:GNOME_BrightnessApplet_Factory"
+#define GPM_BRIGHTNESS_APPLET_ID		"BrightnessApplet"
+#define GPM_BRIGHTNESS_APPLET_FACTORY_ID	"BrightnessAppletFactory"
 #define GPM_BRIGHTNESS_APPLET_ICON		"gnome-brightness-applet"
 #define GPM_BRIGHTNESS_APPLET_ICON_DISABLED	"gpm-brightness-lcd-disabled"
 #define GPM_BRIGHTNESS_APPLET_ICON_INVALID	"gpm-brightness-lcd-invalid"
@@ -731,7 +731,7 @@ gpm_applet_stop_scroll_events_cb (GtkWidget *widget, GdkEvent  *event)
  * displays about dialog
  **/
 static void
-gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 {
 	GtkAboutDialog *about;
 
@@ -796,7 +796,7 @@ gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *
  * open gpm help
  **/
 static void
-gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+gpm_applet_help_cb (GtkAction *action, gpointer data)
 {
 	gpm_help_display ("applets-brightness");
 }
@@ -810,12 +810,9 @@ gpm_applet_destroy_cb (GtkObject *object)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(object);
 
-	if (applet->monitor != NULL) {
-		g_object_unref (applet->monitor);
-	}
-	if (applet->icon != NULL) {
+	g_bus_unwatch_name (applet->bus_watch_id);
+	if (applet->icon != NULL)
 		g_object_unref (applet->icon);
-	}
 }
 
 /**
@@ -896,25 +893,25 @@ gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
 }
 
 /**
- * monitor_connection_cb:
- * @proxy: The dbus raw proxy
- * @status: The status of the service, where TRUE is connected
- * @screensaver: This class instance
+ * gpm_brightness_applet_name_appeared_cb:
  **/
 static void
-monitor_connection_cb (EggDbusMonitor           *monitor,
-		     gboolean	          status,
-		     GpmBrightnessApplet *applet)
+gpm_brightness_applet_name_appeared_cb (GDBusConnection *connection, const gchar *name, const gchar *name_owner, GpmBrightnessApplet *applet)
 {
-	if (status) {
-		gpm_brightness_applet_dbus_connect (applet);
-		gpm_applet_update_tooltip (applet);
-		gpm_applet_draw_cb (applet);
-	} else {
-		gpm_brightness_applet_dbus_disconnect (applet);
-		gpm_applet_update_tooltip (applet);
-		gpm_applet_draw_cb (applet);
-	}
+	gpm_brightness_applet_dbus_connect (applet);
+	gpm_applet_update_tooltip (applet);
+	gpm_applet_draw_cb (applet);
+}
+
+/**
+ * gpm_brightness_applet_name_vanished_cb:
+ **/
+void
+gpm_brightness_applet_name_vanished_cb (GDBusConnection *connection, const gchar *name, GpmBrightnessApplet *applet)
+{
+	gpm_brightness_applet_dbus_disconnect (applet);
+	gpm_applet_update_tooltip (applet);
+	gpm_applet_draw_cb (applet);
 }
 
 /**
@@ -939,13 +936,14 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
-
-	applet->monitor = egg_dbus_monitor_new ();
-	g_signal_connect (applet->monitor, "connection-changed",
-			  G_CALLBACK (monitor_connection_cb), applet);
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-	egg_dbus_monitor_assign (applet->monitor, connection, GPM_DBUS_SERVICE);
-	gpm_brightness_applet_dbus_connect (applet);
+	/* monitor the daemon */
+	applet->bus_watch_id =
+		g_bus_watch_name (G_BUS_TYPE_SESSION,
+				  GPM_DBUS_SERVICE,
+				  G_BUS_NAME_WATCHER_FLAGS_NONE,
+				  (GBusNameAppearedCallback) gpm_brightness_applet_name_appeared_cb,
+				  (GBusNameVanishedCallback) gpm_brightness_applet_name_vanished_cb,
+				  applet, NULL);
 
 	/* coldplug */
 	applet->call_worked = gpm_applet_get_brightness (applet);
@@ -995,44 +993,56 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 }
 
 /**
- * gpm_applet_bonobo_cb:
- * @_applet: GpmBrightnessApplet instance created by the bonobo factory
- * @iid: Bonobo id
+ * gpm_applet_cb:
+ * @_applet: GpmBrightnessApplet instance created by the applet factory
+ * @iid: Applet id
  *
- * the function called by bonobo factory after creation
+ * the function called by libpanel-applet factory after creation
  **/
 static gboolean
-gpm_applet_bonobo_cb (PanelApplet *_applet, const gchar *iid, gpointer data)
+gpm_applet_cb (PanelApplet *_applet, const gchar *iid, gpointer data)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(_applet);
+	GtkActionGroup *action_group;
+	gchar *ui_path;
 
-	static BonoboUIVerb verbs [] = {
-		BONOBO_UI_VERB ("About", gpm_applet_dialog_about_cb),
-		BONOBO_UI_VERB ("Help", gpm_applet_help_cb),
-		BONOBO_UI_VERB_END
+	static const GtkActionEntry menu_actions [] = {
+		{ "About", GTK_STOCK_ABOUT, N_("_About"),
+		  NULL, NULL,
+		  G_CALLBACK (gpm_applet_dialog_about_cb) },
+		{ "Help", GTK_STOCK_HELP, N_("_Help"),
+		  NULL, NULL,
+		  G_CALLBACK (gpm_applet_help_cb) }
 	};
 
-	if (strcmp (iid, GPM_BRIGHTNESS_APPLET_OAFID) != 0) {
+	if (strcmp (iid, GPM_BRIGHTNESS_APPLET_ID) != 0) {
 		return FALSE;
 	}
 
-	panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
-					   DATADIR,
-					   "GNOME_BrightnessApplet.xml",
-					   NULL, verbs, applet);
+	action_group = gtk_action_group_new ("Brightness Applet Actions");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (action_group,
+				      menu_actions,
+				      G_N_ELEMENTS (menu_actions),
+				      applet);
+	ui_path = g_build_filename (BRIGHTNESS_MENU_UI_DIR, "brightness-applet-menu.xml", NULL);
+	panel_applet_setup_menu_from_file (PANEL_APPLET (applet), ui_path, action_group);
+	g_free (ui_path);
+	g_object_unref (action_group);
+
 	gpm_applet_draw_cb (applet);
 	return TRUE;
 }
 
 /**
- * this generates a main with a bonobo factory
+ * this generates a main with a applet factory
  **/
-PANEL_APPLET_BONOBO_FACTORY
+PANEL_APPLET_OUT_PROCESS_FACTORY
  (/* the factory iid */
- GPM_BRIGHTNESS_APPLET_FACTORY_OAFID,
+ GPM_BRIGHTNESS_APPLET_FACTORY_ID,
  /* generates brighness applets instead of regular gnome applets  */
  GPM_TYPE_BRIGHTNESS_APPLET,
- /* the applet name and version */
- "BrightnessApplet", VERSION,
+ /* the applet name */
+ "BrightnessApplet",
  /* our callback (with no user data) */
- gpm_applet_bonobo_cb, NULL);
+ gpm_applet_cb, NULL);
