@@ -40,9 +40,7 @@
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 
-#include "egg-discrete.h"
 #include "egg-debug.h"
-#include "egg-string.h"
 
 #include "gpm-brightness.h"
 #include "gpm-common.h"
@@ -88,6 +86,41 @@ G_DEFINE_TYPE (GpmBrightness, gpm_brightness, G_TYPE_OBJECT)
 static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer gpm_brightness_object = NULL;
 
+/**
+ * gpm_brightness_helper_strtoint:
+ * @text: The text the convert
+ * @value: The return numeric return value
+ *
+ * Converts a string into a signed integer value in a safe way.
+ *
+ * Return value: %TRUE if the string was converted correctly
+ **/
+static gboolean
+gpm_brightness_helper_strtoint (const gchar *text, gint *value)
+{
+	gchar *endptr = NULL;
+	gint64 value_raw;
+
+	/* invalid */
+	if (text == NULL)
+		return FALSE;
+
+	/* parse */
+	value_raw = g_ascii_strtoll (text, &endptr, 10);
+
+	/* parsing error */
+	if (endptr == text)
+		return FALSE;
+
+	/* out of range */
+	if (value_raw > G_MAXINT || value_raw < G_MININT)
+		return FALSE;
+
+	/* cast back down to value */
+	*value = (gint) value_raw;
+	return TRUE;
+}
+
 /**
  * gpm_brightness_helper_get_value:
  **/
@@ -113,7 +146,7 @@ gpm_brightness_helper_get_value (const gchar *argument)
 	egg_debug ("executing %s retval: %i", command, exit_status);
 
 	/* parse for a number */
-	ret = egg_strtoint (stdout_data, &value);
+	ret = gpm_brightness_helper_strtoint (stdout_data, &value);
 	if (!ret)
 		goto out;
 out:
@@ -331,7 +364,7 @@ gpm_brightness_output_get_percentage (GpmBrightness *brightness, RROutput output
 	if (!ret || min == max)
 		return FALSE;
 	egg_debug ("hard value=%i, min=%i, max=%i", cur, min, max);
-	percentage = egg_discrete_to_percent (cur, (max-min)+1);
+	percentage = gpm_discrete_to_percent (cur, (max-min)+1);
 	egg_debug ("percentage %i", percentage);
 	brightness->priv->shared_value = percentage;
 	return TRUE;
@@ -426,7 +459,7 @@ gpm_brightness_output_set (GpmBrightness *brightness, RROutput output)
 	if (!ret || min == max)
 		return FALSE;
 
-	shared_value_abs = egg_discrete_from_percent (brightness->priv->shared_value, (max-min)+1);
+	shared_value_abs = gpm_discrete_from_percent (brightness->priv->shared_value, (max-min)+1);
 	egg_debug ("percent=%i, absolute=%i", brightness->priv->shared_value, shared_value_abs);
 
 	egg_debug ("hard value=%i, min=%i, max=%i", cur, min, max);
@@ -597,7 +630,7 @@ gpm_brightness_set (GpmBrightness *brightness, guint percentage, gboolean *hw_ch
 	if (!ret) {
 		if (brightness->priv->extension_levels < 0)
 			brightness->priv->extension_levels = gpm_brightness_helper_get_value ("get-max-brightness");
-		brightness->priv->extension_current = egg_discrete_from_percent (percentage, brightness->priv->extension_levels+1);
+		brightness->priv->extension_current = gpm_discrete_from_percent (percentage, brightness->priv->extension_levels+1);
 		ret = gpm_brightness_helper_set_value ("set-brightness", brightness->priv->extension_current);
 	}
 
@@ -646,7 +679,7 @@ gpm_brightness_get (GpmBrightness *brightness, guint *percentage)
 		if (brightness->priv->extension_levels < 0)
 			brightness->priv->extension_levels = gpm_brightness_helper_get_value ("get-max-brightness");
 		brightness->priv->extension_current = gpm_brightness_helper_get_value ("get-brightness");
-		percentage_local = egg_discrete_to_percent (brightness->priv->extension_current, brightness->priv->extension_levels+1);
+		percentage_local = gpm_discrete_to_percent (brightness->priv->extension_current, brightness->priv->extension_levels+1);
 		ret = TRUE;
 	}
 
@@ -708,9 +741,13 @@ gpm_brightness_up (GpmBrightness *brightness, gboolean *hw_changed)
 			if (brightness->priv->extension_current > brightness->priv->extension_levels)
 				brightness->priv->extension_current = brightness->priv->extension_levels;
 			ret = gpm_brightness_helper_set_value ("set-brightness", brightness->priv->extension_current);
+			if (hw_changed != NULL)
+				*hw_changed = ret;
+		} else {
+			ret = TRUE;
+			if (hw_changed != NULL)
+				*hw_changed = FALSE;
 		}
-		if (hw_changed != NULL)
-			*hw_changed = ret;
 		brightness->priv->cache_trusted = FALSE;
 		goto out;
 	}
@@ -759,9 +796,13 @@ gpm_brightness_down (GpmBrightness *brightness, gboolean *hw_changed)
 			if (brightness->priv->extension_current < 0)
 				brightness->priv->extension_current = 0;
 			ret = gpm_brightness_helper_set_value ("set-brightness", brightness->priv->extension_current);
+			if (hw_changed != NULL)
+				*hw_changed = ret;
+		} else {
+			ret = TRUE;
+			if (hw_changed != NULL)
+				*hw_changed = FALSE;
 		}
-		if (hw_changed != NULL)
-			*hw_changed = ret;
 		brightness->priv->cache_trusted = FALSE;
 		goto out;
 	}
