@@ -348,6 +348,9 @@ gpm_dpms_init (GpmDpms *dpms)
 	dpms->priv->display = GDK_DISPLAY_XDISPLAY (gdk_display_get_default());
 	dpms->priv->dpms_capable = DPMSCapable (dpms->priv->display);
 	dpms->priv->timer_id = g_timeout_add_seconds (GPM_DPMS_POLL_TIME, (GSourceFunc)gpm_dpms_poll_mode_cb, dpms);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (dpms->priv->timer_id, "[GpmDpms] poll");
+#endif
 
 	/* ensure we clear the default timeouts (Standby: 1200s, Suspend: 1800s, Off: 2400s) */
 	gpm_dpms_clear_timeouts (dpms);
@@ -389,86 +392,3 @@ gpm_dpms_new (void)
 	return GPM_DPMS (gpm_dpms_object);
 }
 
-
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gpm_dpms_test (gpointer data)
-{
-	GpmDpms *dpms;
-	gboolean ret;
-	GError *error = NULL;
-	EggTest *test = (EggTest *) data;
-
-	if (!egg_test_start (test, "GpmDpms"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get object");
-	dpms = gpm_dpms_new ();
-	if (dpms != NULL)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "got no object");
-
-	/************************************************************/
-	egg_test_title (test, "set on");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set STANDBY");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_STANDBY, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set SUSPEND");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_SUSPEND, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set OFF");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_OFF, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	/************************************************************/
-	egg_test_title (test, "set on");
-	ret = gpm_dpms_set_mode (dpms, GPM_DPMS_MODE_ON, &error);
-	if (ret)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed: %s", error->message);
-
-	g_usleep (2*1000*1000);
-
-	g_object_unref (dpms);
-
-	egg_test_end (test);
-}
-
-#endif
-
